@@ -356,16 +356,17 @@ def _send_tiddler(environ, start_response, tiddler):
     except NoTiddlerError, exc:
         raise HTTP404('%s not found, %s' % (tiddler.title, exc))
 
+    # this will raise 304
+    # have to do this check after we read from the store because
+    # we need the revision, which is sad
     last_modified, etag = _validate_tiddler_headers(environ, tiddler)
 
-    if tiddler.type and tiddler.type != 'None':
+    # XXX If we have content that doesn't look like wikitext,
+    # we send it out straight up rather than using the serializer.
+    if _not_wikitext(tiddler, environ['tiddlyweb.config']):
         mime_type = tiddler.type
         content = tiddler.text
     else:
-        # this will raise 304
-        # have to do this check after we read from the store because
-        # we need the revision, which is sad
-
         serialize_type, mime_type = web.get_serialize_type(environ)
         serializer = Serializer(serialize_type, environ)
         serializer.object = tiddler
@@ -386,6 +387,13 @@ def _send_tiddler(environ, start_response, tiddler):
 
     return [content]
 
+def _not_wikitext(tiddler, config):
+    return (
+            tiddler.type and # type is set
+            tiddler.type != 'None' and # type is not None stringified
+            tiddler.type not in # type is not id'd as wikitext by config
+            config['wikitext_render_map']
+            )
 
 def _send_tiddler_revisions(environ, start_response, tiddler):
     """
